==> egov-common-1.0.3-sources.jar: com/gtis/plat/vo/PfWorkFlowInstanceVo.java <==
package com.gtis.plat.vo;

import java.io.Serializable;
import java.util.Date;

public class PfWorkFlowInstanceVo implements Serializable {

    /**
     *
     */
    private static final long serialVersionUID = -1891407617705773486L;
    String workflowIntanceId;
    String workflowIntanceName;
    Date createTime;
    Date modifyTime;
    String priority;
    String remark;
    int workflowState;
    String proId;
    int handlesDay;
    int timeLimit;
    Date finishTime;
    String regionCode;
    String workflowDefinitionId;
    String createUser;
    Date modifyDate;

    public Date getModifyDate() {
        return modifyDate;
    }

    public void setModifyDate(Date modifyDate) {
        this.modifyDate = modifyDate;
    }

    public String getCreateUser() {
        return createUser;
    }

    public void setCreateUser(String createUser) {
        this.createUser = createUser;
    }

    public String getWorkflowDefinitionId() {
        return workflowDefinitionId;
    }

    public void setWorkflowDefinitionId(String workflowDefinitionId) {
        this.workflowDefinitionId = workflowDefinitionId;
    }

    public String getWorkflowIntanceId() {
        return workflowIntanceId;
    }

    public void setWorkflowIntanceId(String workflowIntanceId) {
        this.workflowIntanceId = workflowIntanceId;
    }

    public String getWorkflowIntanceName() {
        return workflowIntanceName;
    }

    public void setWorkflowIntanceName(String workflowIntanceName) {
        this.workflowIntanceName = workflowIntanceName;
    }

    public Date getCreateTime() {
        return createTime;
    }

    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    public Date getModifyTime() {
        return modifyTime;
    }

    public void setModifyTime(Date modifyTime) {
        this.modifyTime = modifyTime;
    }

    public String getPriority() {
        return priority;
    }

    public void setPriority(String priority) {
        this.priority = priority;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public int getWorkflowState() {
        return workflowState;
    }

    public void setWorkflowState(int workflowState) {
        this.workflowState = workflowState;
    }

    public String getProId() {
        return proId;
    }

    public void setProId(String proId) {
        this.proId = proId;
    }

    public int getHandlesDay() {
        return handlesDay;
    }

    public void setHandlesDay(int handlesDay) {
        this.handlesDay = handlesDay;
    }

    public int getTimeLimit() {
        return timeLimit;
    }

    public void setTimeLimit(int timeLimit) {
        this.timeLimit = timeLimit;
    }

    public Date getFinishTime() {
        return finishTime;
    }

    public void setFinishTime(Date finishTime) {
        this.finishTime = finishTime;
    }

    public String getRegionCode() {
        return regionCode;
    }

    public void setRegionCode(String regionCode) {
        this.regionCode = regionCode;
    }

}

==> egov-common-1.0.8-sources.jar: com/gtis/plat/vo/PfWorkFlowInstanceVo.java <==
package com.gtis.plat.vo;

import java.io.Serializable;
import java.util.Date;

public class PfWorkFlowInstanceVo implements Serializable {

    /**
     *
     */
    private static final long serialVersionUID = -1891407617705773486L;
    String workflowIntanceId;
    String workflowIntanceName;
    Date createTime;
    Date modifyTime;
    String priority;
    String remark;
    int workflowState;
    String proId;
    int handlesDay;
    int timeLimit;
    Date finishTime;
    String regionCode;
    String workflowDefinitionId;
    String createUser;
    Date modifyDate;
    String monitorId;

    public String getMonitorId() {
        return monitorId;
    }

    public void setMonitorId(String monitorId) {
        this.monitorId = monitorId;
    }

    public Date getModifyDate() {
        return modifyDate;
    }

    public void setModifyDate(Date modifyDate) {
        this.modifyDate = modifyDate;
    }

    public String getCreateUser() {
        return createUser;
    }

    public void setCreateUser(String createUser) {
        this.createUser = createUser;
    }

    public String getWorkflowDefinitionId() {
        return workflowDefinitionId;
    }

    public void setWorkflowDefinitionId(String workflowDefinitionId) {
        this.workflowDefinitionId = workflowDefinitionId;
    }

    public String getWorkflowIntanceId() {
        return workflowIntanceId;
    }

    public void setWorkflowIntanceId(String workflowIntanceId) {
        this.workflowIntanceId = workflowIntanceId;
    }

    public String getWorkflowIntanceName() {
        return workflowIntanceName;
    }

    public void setWorkflowIntanceName(String workflowIntanceName) {
        this.workflowIntanceName = workflowIntanceName;
    }

    public Date getCreateTime() {
        return createTime;
    }

    public void setCreateTime(Date createTime) {
        this.createTime = createTime;
    }

    public Date getModifyTime() {
        return modifyTime;
    }

    public void setModifyTime(Date modifyTime) {
        this.modifyTime = modifyTime;
    }

    public String getPriority() {
        return priority;
    }

    public void setPriority(String priority) {
        this.priority = priority;
    }

    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }

    public int getWorkflowState() {
        return workflowState;
    }

    public void setWorkflowState(int workflowState) {
        this.workflowState = workflowState;
    }

    public String getProId() {
        return proId;
    }

    public void setProId(String proId) {
        this.proId = proId;
    }

    public int getHandlesDay() {
        return handlesDay;
    }

    public void setHandlesDay(int handlesDay) {
        this.handlesDay = handlesDay;
    }

    public int getTimeLimit() {
        return timeLimit;
    }

    public void setTimeLimit(int timeLimit) {
        this.timeLimit = timeLimit;
    }

    public Date getFinishTime() {
        return finishTime;
    }

    public void setFinishTime(Date finishTime) {
        this.finishTime = finishTime;
    }

    public String getRegionCode() {
        return regionCode;
    }

    public void setRegionCode(String regionCode) {
        this.regionCode = regionCode;
    }

}
